@@ -82,28 +82,28 @@ loved_food (game_fish_t *fish)
 int
 loved_clean_water (game_aquarium_t *aquarium, game_fish_t *fish)
 {
-  bool love_food = aquarium->clean_water == fish->love_clean_water ? true : false;
+  bool love_clean_water = aquarium->clean_water == fish->love_clean_water ? true : false;
 
-  int points = love_food == true ? 10 : -10;
+  int points = love_clean_water == true ? 10 : -10;
 
   return points;
 }
 
 void
-loop_game (game_fish_t *fish)
+loop_game (game_fish_t *fish, game_aquarium_t *aquarium)
 {
   time_t t;
   srand ((unsigned) time (&t));
 
   for (;;)
     {
-      double interval = 10; /* seconds */
+      double interval = 30; /* seconds */
       time_t start = time (NULL);
       int random_duration = rand() % 13;
 
       sleep (random_duration);
 
-      add_life_hunger_to_fish (random_duration, fish);
+      add_life_hunger_to_fish (random_duration, fish, aquarium);
 
       time_t end = time (NULL);
 
@@ -112,5 +112,5 @@ loop_game (game_fish_t *fish)
       if (seconds_to_sleep > 0)
         sleep (seconds_to_sleep);
     }
-}
 
+}
