@@ -30,6 +30,6 @@ void new_game (fish_t *fish, aquarium_t *aquarium,
 int loved_temp (game_aquarium_t *aquarium, game_fish_t *fish);
 int loved_food (game_fish_t *fish);
 int loved_clean_water (game_aquarium_t *aquarium, game_fish_t *fish);
-void loop_game (game_fish_t *fish);
+void loop_game (game_fish_t *fish, game_aquarium_t *aquarium);
 
 #endif /* GAMEENGINE_H  */
