@@ -25,11 +25,12 @@ along with goldfish. If not, see <http://www.gnu.org/licenses/>. */
 #include <string.h>
 #include <unistd.h>
 #include "fish.h"
+#include "aquarium.h"
 #include "../include/asciifish.h"
 
 int random_life_points (void);
 int input_game (void);
-void add_life_hunger_to_fish (int, game_fish_t *fish);
+void add_life_hunger_to_fish (int, game_fish_t *fish, game_aquarium_t *aquarium);
 void clear_screen (void);
 
 #endif /* INPUT_H */
