@@ -69,7 +69,7 @@ main (void)
         case 4:
           new_game (fish, aquarium, &game_fish, &game_aquarium);
           print_game_fish (game_fish);
-          loop_game (&game_fish);
+          loop_game (&game_fish, &game_aquarium);
           print_game_fish (game_fish);
           break;
         }
